@@ -26,7 +26,7 @@ def run_func(**kwargs):
     config = kwargs.get('config', kwargs.get('__config__', None))
     user_funcs = {
         k: kwargs[k]
-        for k in ['on_init', 'on_bar', 'on_tick','on_order','on_trade','on_open','on_close']
+        for k in ['on_init', 'on_bar', 'on_tick','on_order','on_trade','on_open','on_close','on_market_close']
         if k in kwargs
     }
 
