@@ -20,7 +20,7 @@ class Account(object):
         self.available = 0.0
 
         """冻结资金"""
-        self.fozen_cash = 0.0
+        self.frozen_cash = 0.0
 
         """总市值"""
         self.market_value = 0.0
