@@ -21,8 +21,8 @@ class Position(object):
         """交易所"""
         self.exchange = Exchange.UnKnow
 
-        #"""最新行情价"""
-        #self.last_px = 0.0
+        """最新行情价"""
+        self.last_px = 0.0
 
         """持仓数量"""
         self.quantity = 0
@@ -39,8 +39,11 @@ class Position(object):
         """保证金"""
         self.margin = 0.0
 
-        #"""市值"""
-        #self.value = 0.0
+        """市值"""
+        self.value = 0.0
+
+        """浮动盈亏"""
+        self.profit = 0.0
 
         """今仓"""
         self.today_qty = 0.0
