@@ -2,24 +2,28 @@
 class ITradeApi(object):
     """交易接口"""
 
-    def __init__(self,connectionUrl,apiHost,strategyID,orderChangedCallback,orderExecutionCallback,orderCancelledCallBack):
+    def __init__(self,event_bus):
         """构造函数"""
         pass
 
-    def SendOrder(self,clientOrderID, symbol, exchange, orderSide, price, quantity, orderType, offset,tag):
+    def Init(self):
+        """初始化"""
+        pass
+
+    def SendOrder(self,symbol, exchange, orderSide, price, quantity, orderType, offset):
         """下单"""
         pass
 
-    def CancelOrder(self,orderID,clientOrderID):
+    def CancelOrder(self,order):
         """撤单"""
         pass
 
-    def GetAssetInfo(self):
-        """获取资产信息"""
+    def GetAccount(self):
+        """获取账户信息"""
         pass
 
-    def GetOrder(self,clientOrderID):
-        """根据内联ID号 获取订单详情"""
+    def GetOrder(self,orderId):
+        """获取指定id的委托"""
         pass
 
     def GetOpenOrders(self):
@@ -34,4 +38,6 @@ class ITradeApi(object):
         """获取持仓"""
         pass
 
-
+    def GetTrades(self):
+        """获取当日成交"""
+        pass
\ No newline at end of file
