@@ -68,7 +68,7 @@ class PushQuoteSubscriber(object):
                 self.__wirteError("subscribe failed!")
             logger.debug("连接成功，推送验证信息完成")
         except Exception as e:
-            logger.error('live trade subscribe exception',e)
+            logger.exception(e)
 
     def __wirteError(self, error):
         '''写错误日志'''
