@@ -30,57 +30,50 @@ class RealTradeApi(ITradeApi):
         self.__event_bus = event_bus
 
         self.__api_core = RealTradeApiCore()
-        self.__user_info = None
-
-    def Init(self):
-        """初始化"""
-        user = UserInfo()
-
-        info = Environment.get_instance().config.acct_info
 
+        acct_info = Environment.get_instance().config.acct_info
         # 设置策略id
-        strategy_id = info['strategy_id']
-        self.__strategy_id = strategy_id
+        self.__strategy_id = acct_info['strategy_id']
 
+        self.__user_info = self.__get_user(acct_info) 
+
+        # 保存user变量
+        self.__api_core.SetUserInfo(self.__user_info)       
+
+    def __get_user(self,acct_info):
         # 初始化user变量
-        brokerType = info['broker_type']
-        counterId = info['comp_counter']
-        crypt =('crypt' in info) and info['crypt']
-        aid = info['account']
-        psd = info['password']
+        user = UserInfo()
+        crypt =('crypt' in acct_info) and acct_info['crypt']
+        aid = acct_info['account']
+        psd = acct_info['password']
         if crypt:
             user.AccountID = decrypt(aid)
             user.PassWord = decrypt(psd)
         else:
             user.AccountID = aid
             user.PassWord = psd
-        user.BrokerType = brokerType
-        user.CounterID = counterId
+        user.BrokerType = acct_info['broker_type']
+        user.CounterID = acct_info['comp_counter']
+        return user
+
+    def Init(self):
+        """初始化"""
 
         # 按照指定的期货公司id和柜台id获取对应的柜台
-        api = self.__api_core
-        counterInfo = api.GetCounterInfo(brokerType)
-        counters = list(filter(lambda x:x.CounterId == counterId, counterInfo.CounterList))
-        if(None ==  counters or len(counters) == 0):raise Exception("没有对应的柜台id")
+        counterInfo = self.__api_core.GetCounterInfo(self.__user_info.BrokerType)
+        counters = list(filter(lambda x:x.CounterId == self.__user_info.CounterID, counterInfo.CounterList))
+        if(None ==  counters or len(counters) == 0):
+            raise Exception("没有对应的柜台id")
         counter = counters[0]
-        counterApi = api.GetCounterApi(counter)
+        counterApi = self.__api_core.GetCounterApi(counter)
 
         # 设置user变量的柜台信息
-        user.SupInfo.TradeCounter = counter.TradeCounter
-        user.ApiInfoId = counterApi.ApiInfoId
-        user.CounterAddr = counterApi.ApiAddr
+        self.__user_info.SupInfo.TradeCounter = counter.TradeCounter
+        self.__user_info.ApiInfoId = counterApi.ApiInfoId
+        self.__user_info.CounterAddr = counterApi.ApiAddr
 
-        # 登录并设置user变量的TradeToken
-        self.__wirteInfo('登录!')
-        login = api.AccountLogin(user)
-        if (None ==  login) : raise Exception('登录失败!')
-        user.TradeToken = login.TradeToken
-
-        # 保存user变量
-        self.__user_info = user
-        api.SetUserInfo(user)
-
-        self.__startReLoginMonitor()
+        self.__login()
+        Timer(30, self.__auto_relogin).start()
         
         # 设置推送
         self.__wirteInfo('设置推送!')
@@ -88,9 +81,8 @@ class RealTradeApi(ITradeApi):
         cfg.address = counterApi.wsAddr
         cfg.hbContent = json.dumps({ 'requestType' : RequestType.HeartBeat.name,'reqId' : '' })
         cfg.recvCallback = self.__OnRecv
-        subscriber = PushQuoteSubscriber(cfg, strategy_id, user)
-        subscriber.Connect()
-        self.__subscriber = subscriber
+        self.__subscriber = PushQuoteSubscriber(cfg, self.__strategy_id, self.__user_info)
+        self.__subscriber.Connect()
 
         self.__wirteInfo('初始化完成!')
         return True
@@ -166,9 +158,8 @@ class RealTradeApi(ITradeApi):
 
         params = {'orderId':cancelOrder.order_id,'strategyId':self.__strategy_id,'tradeAccount': self.__user_info.AccountID}
         logger.info("begin cancelorder，param:{0}".format(json.dumps(params,ensure_ascii=False)))
-        
         model = self.__api_core.CancelOrder(cancelOrder.order_id)
-        result = model.ErrorNo == 0
+        self.__wirteInfo(f'cancelorder complated，param:{json.dumps(params,ensure_ascii=False)},resp:{json.dumps(model,ensure_ascii=False)}')
 
         newCancelOrder = self.GetOrder(order.order_id)
 
@@ -294,24 +285,31 @@ class RealTradeApi(ITradeApi):
         trade.filled_time = datetime.strptime(data['filledTime'],'%Y-%m-%d %H:%M:%S')
         return trade
 
-    def __startReLoginMonitor(self):
-        model = self.__api_core.GetAccountFund()
-        if(self.__needReLogin(model)):
-            self.__reLogin()
-        Timer(30, self.__startReLoginMonitor).start()
-    
-    def __reLogin(self):
-        self.__wirteInfo('重新登录!')
-        api = self.__api_core
-        user = self.__user_info
-        login = api.AccountLogin(user)
-        if (None ==  login) : return
-        user.TradeToken = login.TradeToken
-        self.__user_info = user
-        api.SetUserInfo(user)
+    def __auto_relogin(self):
 
-    def __needReLogin(self, model):
-        return model != None and model.ErrorNo == 1
+        try:
+            model = self.__api_core.GetAccountFund()
+            if(model == None or model.ErrorNo == 1):
+                self.__login()
+        except Exception as e:
+            logger.exception(e)
+            self.__login()
+        finally:
+            Timer(30, self.__auto_relogin).start()
+    
+    def __login(self):
+        # 登录并设置user变量的TradeToken
+        
+        try:
+            self.__wirteInfo('登录!')
+            login = self.__api_core.AccountLogin(self.__user_info)
+            if (None ==  login) :
+                self.__wirteError("尝试登录失败!!!")
+                return
+            self.__user_info.TradeToken = login.TradeToken
+            self.__wirteInfo('登录成功!')
+        except Exception as e:
+            logger.exception(e)        
 
     def __wirteError(self, error):
         '''写错误日志'''
